@@ -11,10 +11,10 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+from assertionengine import AssertionOperator
 
 from .browser import Browser
 from .utils.data_types import (
-    AssertionOperator,
     ColorScheme,
     ElementState,
     KeyboardModifier,
